@@ -304,10 +304,10 @@ class trains_data_loader:
         self.test_X = pd.DataFrame()
         self.test_y = pd.DataFrame()
 
-        trains_start_year = trains_start[0:4]
-        trains_end_year = trains_end[0:4]
-        test_start_year = test_start[0:4]
-        test_end_year = test_end[0:4]
+        # trains_start_year = trains_start[0:4]
+        # trains_end_year = trains_end[0:4]
+        # test_start_year = test_start[0:4]
+        # test_end_year = test_end[0:4]
         file_list = os.listdir(self.module_path + self.feature_dir)
         for index, file in enumerate(file_list):
             print(f"读取进度:{(index / len(file_list)) * 100}")
